import * as d3 from 'd3';

var data = {
  name: 'A1',
  children: [
    {
      name: 'B1',
      children: [
        {
          name: 'C1',
          value: 100,
        },
        {
          name: 'C2',
          value: 300,
        },
        {
          name: 'C3',
          value: 200,
        },
      ],
    },
    {
      name: 'B2',
      value: 200,
    },
  ],
};

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  var treemapLayout = d3
    .treemap()
    .size([800, 400])
    .paddingOuter(16);

  var rootNode = d3.hierarchy(data);
  rootNode.sum((d) => d.value);

  treemapLayout(rootNode);

  const svg = d3
    .select(container)
    .selectAll('svg')
    .data([1])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  //  Nodes
  const nodes = svg
    .selectAll('g')
    .data(rootNode.descendants())
    .join('g')
    .style(
      'transform',
      (d) => `translate(${d.x0}px, ${d.y0}px)`,
    );

  nodes
    .append('rect')
    .attr('width', (d) => d.x1 - d.x0)
    .attr('height', (d) => d.y1 - d.y0)
    .attr('fill', 'cadetblue')
    .attr('opacity', 0.3)
    .attr('stroke', 'white');

  nodes
    .append('text')
    .attr('dx', 4)
    .attr('dy', 14)
    .text((d) => d.data.name)
    .attr('fill', 'white')
    .attr('fill-size', '10px')
    .attr('font-family', 'Helvetica Neue');
};
